#ifndef __PACKET_H__
#define __PACKET_H__

#define ETHERNET_BROADCAST "FFFFFFFFFFFF"
#define IP_BROADCAST       "FF"

/* Layer 2 Protocollen */
#define P2_0000 "RAW"
#define P2_0001 "ETHERNET"
#define P2_0002 "LOOPBACK"
#define P2_UNKN "UNKWON"

#define P2N_RAW   0x0000
#define P2N_ETH   0x0001
#define P2N_LO    0x0002
#define P2N_UNKN  0xFFFF

/* Layer 3 Protocollen */
#define P3_0800 "IP"
#define P3_0806 "ARP"
#define P3_UNKN "?"

#define P3N_IPX   0x8137
#define P3N_IP    0x0800  
#define P3N_ARP   0x0806
#define P3N_UNKN  0xFFFF

#define P3_ETHII   "Ethernet_II - IPX"
#define P3_ETH8023 "Ethernet_802.3 - IPX"
#define P3_8023    "802.3 - IPX"
#define P3_ETHSNAP "Ethernet_SNAP"

#define P3N_ETHII   0x80
#define P3N_ETH8023 0x81
#define P3N_8023    0x82
#define P3N_ETHSNAP 0x83

/* ARP Operations */
#define ARP_0001 "ARP Request"
#define ARP_0002 "ARP Reply"
#define ARP_0003 "RARP Request"
#define ARP_0004 "RARP Reply"

/* Layer 4 Protocollen */
#define P4_0001 "ICMP"
#define P4_0006 "TCP"
#define P4_0017 "UDP"

#define P4_0005 "SPX"

#define P4N_ICMP 0x01
#define P4N_TCP  0x06
#define P4N_UDP  0x11

#define P4N_SPX  0x05
#define P4N_UNKN 0xFFFF

/* Header lengths */

#define ETHERNET_HEADER_LENGTH 14
#define IP_HEADER_LENGTH       20
#define ARP_HEADER_LENGTH      28
#define IPX_HEADER_LENGTH      30
#define SPX_HEADER_LENGTH      12
#define TCP_HEADER_LENGTH      20
#define UDP_HEADER_LENGTH       8

#include "types.h"
#include <sys/types.h>
#include <stdio.h>

typedef struct tICMPTypes
    {
        int iTypeNr;
	char * sString;
    } tICMPTypes;


typedef struct packet
       {
           int iOSILayer2Prot;           // Standaard is Ethernet (0x0001)
	   int iOSILayer3Prot;           // IPX/IP/ARP
	   int iOSILayer4Prot;           // SPX / ICMP/UDP/TCP
	   int iPacketLength;            // Totale lengte pakketje
	   char cData[256];
	   u_int16_t uiDataLength;
        // TIJD
           struct tijd tBegin;
        // ETHERNET
	   struct ethernet_addr eaEthDestination;
	   struct ethernet_addr eaEthSource;
           u_int16_t iEthernetProtocol;
	// IPX (Ethernet type 0600)
	   u_int8_t uiIPXSubType;
	   u_int16_t uiIPXChecksum;
	   u_int16_t uiIPXLength;
	   u_int8_t uiIPXTransportControl;
	   u_int8_t uiIPXPacketType;
	   struct ipx_addr ipaIPXSource;
	   struct ipx_addr ipaIPXDestination;    
	// SPX (IPX type 5)
	   u_int8_t uiSPXConnectionControl;
	   u_int8_t uiSPXDatastreamType;
	   u_int16_t uiSPXSourceConnectionID;
	   u_int16_t uiSPXDestinationConnectionID;
	   u_int16_t uiSPXSequenceNr;
	   u_int16_t uiSPXAckNr;
	   u_int16_t uiSPXAllocationNr;    
        // IP (Ethernet type 0800)
	   byte bIPVersion;
	   byte bIPHeaderLength;
	   byte bIPTypeOfService;
	   u_int16_t uiIPTotalLength;
	   u_int16_t uiIPID;
	   bit bIPDontFragment;
	   bit bIPMoreFragments;
	   u_int16_t uiIPFragmentOffset;
	   u_int8_t uiIPTimeToLive;
	   byte bIPProtocol;
	   u_int16_t uiIPHeaderChecksum;
	   struct ip_addr iaIPSource;
	   struct ip_addr iaIPDestination;
	// ICMP-Echo (IP type 1);
	   u_int8_t uiICMPType;
	   u_int8_t uiICMPCode;
	   u_int16_t uiICMPChecksum;
	   u_int16_t uiICMPEchoID;
	   u_int16_t uiICMPEchoSequenceNr;
	// TCP (IP type 6);
	   u_int16_t uiTCPSourcePort;
	   u_int16_t uiTCPDestinationPort;
	   u_int32_t uiTCPSequenceNr;
	   u_int32_t uiTCPAckNr;
	   u_int8_t uiTCPHeaderLength;      // In veelvouden van 32 bits
	   u_int16_t uiTCPFlags;
	   u_int16_t uiTCPWindow;
	   u_int16_t uiTCPChecksum;
	   u_int16_t uiTCPUrgentPointer;
	// UDP (IP type 17);
	   u_int16_t uiUDPSourcePort;
	   u_int16_t uiUDPDestinationPort;
	   u_int16_t uiUDPHeaderLength;      // Totaal van UDP header en Data
	   u_int16_t uiUDPChecksum;
	// ARP (Ethernet type 0806)
	   u_int16_t uiARPHardwareType;      // Meestal 1 (Ethernet)
	   u_int16_t uiARPProtocolType;      // Meestal 800 (IP)
	   u_int8_t uiARPHardwareLength;     // Aantal bytes van adres
	   u_int8_t uiARPProtocolLength;
	   u_int16_t uiARPOperation;         // 1 - 4
	   struct ethernet_addr eaSender;
	   struct ip_addr iaSender;
	   struct ethernet_addr eaTarget;
	   struct ip_addr iaTarget;
} packet;

void ParsePacket (const u_char* pack, packet* pakketje, const u_int uLLC);

#endif