/*******************************************************************************
**                                                                            **
**  File:        db_interface.c                                               **
**  Description: Main file of the packet capture program.                     **
**  Author:      Derick Rethans / Bjorn Vermeulen / Jeroen Scheeres           **
**  Date:        1999-06-02                                                   **
**  Version:     1.0                                                          **
**  Lines:       656                                                          **
**                                                                            **
*******************************************************************************/

#include <string.h>
#include "c.h"
#include "util.h"
#include "packet.h"

#include "trigger_inst.h"
#include "filter_inst.h"

#include <mysql/mysql.h>
#include <db_interface.h>

MYSQL* conn;   

/************* FUNCTIONS ******************************************************/

MYSQL_RES* DBExec (MYSQL* conn, char * pcString)
{
    int iReturn;
    bool bSelfConnect = false;
    
    if (conn == NULL)
    {
        conn = InitDBConn();
	bSelfConnect = true;
    }

    if ((iReturn = mysql_query (conn, pcString)) == 0)
    {
        return mysql_store_result (conn);
    }
    else
    {
        return NULL;
    }
    
    if (bSelfConnect)
    {
        TerminateDBConn (conn);
    }
}

void EmptyPackets (void)
{
    char         pcString[512];
    MYSQL_RES   *result;

    sprintf (pcString, "DELETE FROM arp WHERE (1=1)");
    result = DBExec (conn, pcString);			
    sprintf (pcString, "DELETE FROM icmp WHERE (1=1)");
    result = DBExec (conn, pcString);			
    sprintf (pcString, "DELETE FROM ip WHERE (1=1)");
    result = DBExec (conn, pcString);			
    sprintf (pcString, "DELETE FROM ipx WHERE (1=1)");
    result = DBExec (conn, pcString);			
    sprintf (pcString, "DELETE FROM packet WHERE (1=1)");
    result = DBExec (conn, pcString);			
    sprintf (pcString, "DELETE FROM spx WHERE (1=1)");
    result = DBExec (conn, pcString);			
    sprintf (pcString, "DELETE FROM tcp WHERE (1=1)");
    result = DBExec (conn, pcString);			
    sprintf (pcString, "DELETE FROM udp WHERE (1=1)");
    result = DBExec (conn, pcString);			
}

void PutStatusData (int iState,
                    int iTotPack, int iSnifPack, int iFiltPack,
		    int iSnifData, int iFiltData)
{
    char         pcString[512];
    MYSQL_RES   *result;

    result = DBExec (conn, "DELETE FROM status where 1=1");
    sprintf (pcString, 
             "INSERT INTO status VALUES (0, %d, %d, %d, %d, %d, %d)",
             iState, iTotPack, iSnifPack, iFiltPack, iSnifData, iFiltData);
    result = DBExec (conn, pcString);
    mysql_free_result (result);
}

void GetStatusData (int *iState, 
                    int *iTotPack, int *iSnifPack, int *iFiltPack,
		    int *iSnifData, int *iFiltData)
{
    char         pcString[512];
    MYSQL_RES   *result;
    MYSQL_FIELD *fields;
    MYSQL_ROW    row;

    do
    {
        sprintf (pcString, "SELECT * FROM status");
        result = DBExec (conn, pcString);
        if (result == 0)
        {
            mysql_free_result (result);
        }
    }
    while (result == 0);
    fields = mysql_fetch_fields (result);
    
    row = mysql_fetch_row (result);
    
    if (row != NULL)  /* if there is no record skip */
    {
       *iState = atoi (row[1]);
       *iTotPack = atoi (row[2]);
       *iSnifPack = atoi (row[3]);
       *iFiltPack = atoi (row[4]);
       *iSnifData = atoi (row[5]);
       *iFiltData = atoi (row[6]);
    }
    else
    {
       *iState = 0;
    } 
}

void PutCall (int iCallID)
{
    char         pcString[512];
    MYSQL_RES   *result;

    result = DBExec (conn, "DELETE FROM status where 1=1");
    mysql_free_result (result);
    sprintf (pcString, 
             "INSERT INTO status VALUES (%d, 0, 0, 0, 0, 0, 0)", iCallID);
    result = DBExec (conn, pcString);
    mysql_free_result (result);
}

int GetCall (void)
{
    char         pcString[512];
    MYSQL_RES   *result;
    MYSQL_FIELD *fields;
    MYSQL_ROW    row;

    do
    {
        sprintf (pcString, "SELECT CallID FROM status");
        result = DBExec (conn, pcString);
        if (result == 0)
        {
            mysql_free_result (result);
        }
    }
    while (result == 0);
    fields = mysql_fetch_fields (result);
    row = mysql_fetch_row (result);
    
    if (row != NULL)  /* if there is no record skip */
    {
       return atoi (row[0]);
    }
    else
    {
       return 0;
    } 
}

bool GetTriggerSetting (const char* sSettingName, struct trigger_setting* trSetting)
{
    char         pcString[512];
    MYSQL_RES   *result;
    MYSQL_FIELD *fields;
    MYSQL_ROW    row;

    do
    {
        sprintf (pcString, "SELECT * FROM trigger WHERE name='%s'", sSettingName);
        result = DBExec (conn, pcString);
        if (result == 0)
        {
            mysql_free_result (result);
        }
    }
    while (result == 0);
    
    fields = mysql_fetch_fields(result);
    row = mysql_fetch_row(result);
    
    if (row != NULL)
    {
        strncpy (trSetting->sNaam, row[0], MAX_NAAM_LENGTH);
	trSetting->iStartType = row[1][0] - 0x30;
	trSetting->iStopType  = row[2][0] - 0x30;
    
        DBToString ((char *) &trSetting->tBegin,      row[3], 4);
  	DBToString ((char *) &trSetting->tBegin +  4, row[4], 2);
        DBToString ((char *) &trSetting->tBegin +  6, row[5], 2);
	DBToString ((char *) &trSetting->tBegin +  8, row[6], 2);
        DBToString ((char *) &trSetting->tBegin + 10, row[7], 2);
	DBToString ((char *) &trSetting->tBegin + 12, row[8], 2);
        
        DBToString ((char *) &trSetting->tStop,      row[ 9], 4);
  	DBToString ((char *) &trSetting->tStop +  4, row[10], 2);
        DBToString ((char *) &trSetting->tStop +  6, row[11], 2);
	DBToString ((char *) &trSetting->tStop +  8, row[12], 2);
        DBToString ((char *) &trSetting->tStop + 10, row[13], 2);
	DBToString ((char *) &trSetting->tStop + 12, row[14], 2);

        trSetting->bEthernetSrcSpec = (row[15][0] == '1') ? true : false;
        DBToString ((char *) &trSetting->eaSource, row[16], 12);
        trSetting->bEthernetDestSpec = (row[17][0] == '1') ? true : false;
        DBToString ((char *) &trSetting->eaDestination, row[18], 12);
        trSetting->bEthernetProtocolSpec = (row[19][0] == '1') ? true : false;
        trSetting->iEthernetProtocol = atoi(row[20]);        
        
        trSetting->bIPSrcSpec = (row[21][0] == '1') ? true : false;
        DBToString ((char *) &trSetting->iaSource, row[22], 8);
        trSetting->bIPDestSpec = (row[23][0] == '1') ? true : false;
        DBToString ((char *) &trSetting->iaDestination, row[24], 8);
        trSetting->bIPSrcPortSpec = (row[25][0] == '1') ? true : false;
        trSetting->iIPSrcPort = atoi(row[26]);        
        trSetting->bIPDestPortSpec = (row[27][0] == '1') ? true : false;
        trSetting->iIPDestPort = atoi(row[28]);        
        trSetting->bIPProtocolSpec = (row[29][0] == '1') ? true : false;
        trSetting->iIPProtocol = atoi(row[30]);        
        
        trSetting->bIPXSrcNetSpec = (row[31][0] == '1') ? true : false;
        DBToString ((char *) &trSetting->ipaSource, row[32], 8);
        trSetting->bIPXSrcHostSpec = (row[33][0] == '1') ? true : false;
        DBToString ((char *) &trSetting->ipaSource+8, row[34], 12);
        trSetting->bIPXSrcSocketSpec = (row[35][0] == '1') ? true : false;
        DBToString ((char *) &trSetting->ipaSource+20, row[36], 4);
        trSetting->bIPXDestNetSpec = (row[37][0] == '1') ? true : false;
        DBToString ((char *) &trSetting->ipaDestination, row[38], 8);
        trSetting->bIPXDestHostSpec = (row[39][0] == '1') ? true : false;
        DBToString ((char *) &trSetting->ipaDestination+8, row[40], 12);
        trSetting->bIPXDestSocketSpec = (row[41][0] == '1') ? true : false ;
        DBToString ((char *) &trSetting->ipaDestination + 20, row[42], 4);
        trSetting->bIPXProtocolSpec = (row[43][0] == '1') ? true : false;
        trSetting->uiIPXProtocol = atoi(row[44]);        
        trSetting->bAantalPakkettenSpec = (row[45][0] == '1') ? true : false;
        trSetting->iAantalPakketten = atoi(row[46]);        
        trSetting->bIPDuplex = (row[47][0] == '1') ? true : false;

        mysql_free_result (result);
        return true;
    }
    else
    {
       return false;
    } 
}

bool GetFilterSetting (const char* sFilterName, struct filter_setting* fsSetting)
{
    char         pcString[512];
    MYSQL_RES   *result;
    MYSQL_FIELD *fields;
    MYSQL_ROW    row;

    do
    {
        sprintf (pcString, "SELECT * FROM filter WHERE name='%s'", sFilterName);
        result = DBExec (conn, pcString);
        if (result == 0)
        {
            mysql_free_result (result);
        }
    }
    while (result == 0);
    fields = mysql_fetch_fields(result);
    row = mysql_fetch_row(result);
    
    if (row != NULL)
    {
        strncpy (fsSetting->sNaam, row[0], MAX_NAAM_LENGTH);
	fsSetting->iType = row[1][0] - 0x30;
    
        fsSetting->bEthernetSrcSpec = (row[2][0] == '1') ? true : false;
        DBToString ((char *) &fsSetting->eaSource, row[3], 12);
        fsSetting->bEthernetDestSpec = (row[4][0] == '1') ? true : false;
        DBToString ((char *) &fsSetting->eaDestination, row[5], 12);
        fsSetting->bEthernetProtocolSpec = (row[6][0] == '1')  ? true : false;
        fsSetting->iEthernetProtocol = atoi(row[7]);        
        
        fsSetting->bIPSrcSpec = (row[8][0] == '1')  ? true : false;
        DBToString ((char *) &fsSetting->iaSourceMask, row[9], 8);
        fsSetting->bIPDestSpec = (row[10][0] == '1')  ? true : false;
        DBToString ((char *) &fsSetting->iaDestinationMask, row[11], 8);
        fsSetting->bIPSrcPortSpec = (row[12][0] == '1') ? true : false;
        fsSetting->iIPSrcPort = atoi(row[13]);        
        fsSetting->bIPDestPortSpec = (row[14][0] == '1') ? true : false;
        fsSetting->iIPDestPort = atoi(row[15]);        
        fsSetting->bIPProtocolSpec = (row[16][0] == '1') ? true : false;
        fsSetting->iIPProtocol = atoi(row[17]);        
        
        fsSetting->bIPXSrcNetSpec = (row[18][0] == '1') ? true : false;
        DBToString ((char *) &fsSetting->ipaSource, row[19], 8);
        fsSetting->bIPXSrcHostSpec = (row[20][0] == '1') ? true : false;
        DBToString ((char *) &fsSetting->ipaSource+8, row[21], 12);
        fsSetting->bIPXSrcSocketSpec = (row[22][0] == '1') ? true : false;
        DBToString ((char *) &fsSetting->ipaSource+20, row[23], 4);
        fsSetting->bIPXDestNetSpec = (row[24][0] == '1') ? true : false;
        DBToString ((char *) &fsSetting->ipaDestination, row[25], 8);
        fsSetting->bIPXDestHostSpec = (row[26][0] == '1') ? true : false;
        DBToString ((char *) &fsSetting->ipaDestination+8, row[27], 12);
        fsSetting->bIPXDestSocketSpec = (row[28][0] == '1') ? true : false;
        DBToString ((char *) &fsSetting->ipaDestination+20, row[29], 4);
        fsSetting->bIPXProtocolSpec = (row[30][0] == '1') ? true : false;
        fsSetting->uiIPXProtocol = atoi(row[31]);
        fsSetting->bIPDuplex = (row[32][0] == '1') ? true : false;
        
        mysql_free_result (result);
        return true;
    }
    else
    {
       return false;
    } 
}

void PutPacketData (const struct packet* pk)
{
    char        pcString[1536];
    MYSQL_RES  *result;
    char        pcTijd[21];
    char        pcEthDestination[13];
    char        pcEthSource[13];
    
    char        pcIPXDestNetwork[5];
    char        pcIPXDestHost[7];    
    char        pcIPXDestSocket[3];
    char        pcIPXSrcNetwork[5];
    char        pcIPXSrcHost[7];    
    char        pcIPXSrcSocket[3];
    
    char        pcIPSrcAddr[9];
    char        pcIPDestAddr[9];
    char	pcBuffer[1024];
    int		iRealLength;
    
    strncpy (pcTijd, pk->tBegin.cYear, 20);
    pcTijd[20] = 0;
    
    strncpy (pcEthDestination, pk->eaEthDestination.addr, 12);
    pcEthDestination[12] = 0;
    strncpy (pcEthSource, pk->eaEthSource.addr, 12);
    pcEthSource[12] = 0;
    
    strncpy (pcIPXDestNetwork, pk->ipaIPXDestination.networkaddr, 4);
    pcIPXDestNetwork[4] = 0;
    strncpy (pcIPXDestHost, pk->ipaIPXDestination.hostaddr, 6);
    pcIPXDestHost[6] = 0;
    strncpy (pcIPXDestSocket, pk->ipaIPXDestination.socketaddr, 2);
    pcIPXDestSocket[2] = 0;
    strncpy (pcIPXSrcNetwork, pk->ipaIPXSource.networkaddr, 4);
    pcIPXSrcNetwork[4] = 0;
    strncpy (pcIPXSrcHost, pk->ipaIPXSource.hostaddr, 6);
    pcIPXSrcHost[6] = 0;
    strncpy (pcIPXSrcSocket, pk->ipaIPXSource.socketaddr, 2);
    pcIPXSrcSocket[2] = 0;
    
    strncpy (pcIPSrcAddr, pk->iaIPSource.addr, 8);
    pcIPSrcAddr[8] = 0;
    strncpy (pcIPDestAddr, pk->iaIPDestination.addr, 8);
    pcIPDestAddr[8] = 0;
    

    // Insert info from sniffer into packet
    sprintf (pcString, "INSERT INTO packet VALUES ('%s', %d, %d, %d, '%s', '%s', %d, %d, '');",
             pcTijd,
             pk->iOSILayer2Prot,
             pk->iOSILayer3Prot,
             pk->iOSILayer4Prot,
             pcEthDestination,
             pcEthSource,
             pk->iEthernetProtocol,
             pk->iPacketLength);
    result = DBExec (conn, pcString);
    
    iRealLength = mysql_escape_string (pcBuffer, pk->cData, pk->uiDataLength);
    sprintf (pcString, "UPDATE packet SET snifstuff = '%s' WHERE timestamp='%s'", 
	     pcBuffer, pcTijd);

    if (mysql_real_query (conn, pcString, iRealLength + 51 + 20) == 0)
    {
        result = mysql_store_result (conn);
    }
    else
    {
        result = NULL;
    }
    printf ("%s", mysql_error(conn));
    
    if (pk->iOSILayer3Prot == P3N_IPX)
    {
	// Insert info from sniffer into ipx
        sprintf (pcString, "INSERT INTO ipx VALUES ('%s', %d, %d, %d, %d, '%s', '%s', '%s', '%s', '%s', '%s');",
                 pcTijd,
                 pk->uiIPXSubType,
                 pk->uiIPXLength,
                 pk->uiIPXTransportControl,
                 pk->uiIPXPacketType,
                 pk->ipaIPXDestination.networkaddr,
                 pk->ipaIPXDestination.hostaddr,
                 pk->ipaIPXDestination.socketaddr,
                 pk->ipaIPXSource.networkaddr,
                 pk->ipaIPXSource.hostaddr,
                 pk->ipaIPXSource.socketaddr);
	result = DBExec (conn, pcString);
    }

    if (pk->iOSILayer3Prot == P3N_IP)
    {
	sprintf (pcString, "INSERT INTO ip VALUES ('%s', %d, %d, %d, %d, %d, %d, %d, %d, %d, %d, '%s', '%s');",
                 pcTijd,
                 pk->bIPVersion,
                 pk->bIPHeaderLength,
                 pk->bIPTypeOfService,
                 pk->uiIPTotalLength,
                 pk->uiIPID,
                 pk->bIPDontFragment,
                 pk->bIPMoreFragments,
                 pk->uiIPFragmentOffset,
                 pk->uiIPTimeToLive,
                 pk->bIPProtocol,
                 pcIPSrcAddr,
                 pcIPDestAddr);
        result = DBExec (conn, pcString);			
    }

    if (pk->iOSILayer3Prot == P3N_ARP && pk->iOSILayer2Prot == P2N_ETH)
    {
	sprintf (pcString, "INSERT INTO arp VALUES ('%s', %d, %d, %d, %d, %d, '%s', '%s', '%s', '%s');",
                 pcTijd,
                 pk->uiARPHardwareType,
                 pk->uiARPProtocolType,
                 pk->uiARPHardwareLength,
                 pk->uiARPProtocolLength,
                 pk->uiARPOperation,
                 pk->eaSender.addr,
                 pk->iaSender.addr,
                 pk->eaTarget.addr,
                 pk->iaTarget.addr);
	result = DBExec (conn, pcString);	
    }		

    if (pk->iOSILayer4Prot == P4N_SPX && pk->iOSILayer3Prot == P3N_IPX)
    {
	sprintf (pcString, "INSERT INTO spx VALUES ('%s', %d, %d, %d, %d, %d, %d, %d);",
                 pcTijd,
                 pk->uiSPXConnectionControl,
                 pk->uiSPXDatastreamType,
                 pk->uiSPXSourceConnectionID,
                 pk->uiSPXDestinationConnectionID,
                 pk->uiSPXSequenceNr,
                 pk->uiSPXAckNr,
                 pk->uiSPXAllocationNr);
	result = DBExec (conn, pcString);
    }

    if (pk->iOSILayer4Prot == P4N_ICMP && pk->iOSILayer3Prot == P3N_IP)
    {
        sprintf (pcString, "INSERT INTO icmp VALUES ('%s', %d, %d, %d, %d);",
                 pcTijd,
                 pk->uiICMPType,
                 pk->uiICMPCode,
                 pk->uiICMPEchoID,
                 pk->uiICMPEchoSequenceNr);
	result = DBExec (conn, pcString);			
    }

    if (pk->iOSILayer4Prot == P4N_TCP && pk->iOSILayer3Prot == P3N_IP)
    {
	sprintf (pcString, "INSERT INTO tcp VALUES ('%s', %d, %d, %d, %d, %d, %d, %d);",
                 pcTijd,
                 pk->uiTCPSourcePort,
                 pk->uiTCPDestinationPort,
                 pk->uiTCPSequenceNr,
                 pk->uiTCPAckNr,
                 pk->uiTCPHeaderLength,
                 pk->uiTCPFlags,
                 pk->uiTCPWindow);
	result = DBExec (conn, pcString);			
    }
	
    if (pk->iOSILayer4Prot == P4N_UDP && pk->iOSILayer3Prot == P3N_IP)
    {
	sprintf (pcString, "INSERT INTO udp VALUES ('%s', %d, %d, %d);",
                 pcTijd,
                 pk->uiUDPSourcePort,
                 pk->uiUDPDestinationPort,
                 pk->uiUDPHeaderLength);
        result = DBExec (conn, pcString);			
    }


}
/*
void InitDB (void)
{
    if ((mysql_select_db (conn, "wespdb")))
    {
	fprintf (stderr, "Connection to database failed.\n");
	fprintf (stderr, "%s\n", mysql_error (conn));
	exit(-1);
    }
}
*/
MYSQL* InitDBConn (void)
{
    MYSQL* mConn;
    
    mConn = mysql_connect (NULL, NULL, NULL, NULL);
    if ((mysql_select_db (mConn, "wespdb")))
    {
	fprintf (stderr, "Connection to database failed.\n");
	fprintf (stderr, "%s\n", mysql_error (mConn));
	exit (-1);
    }
    return mConn;
}

void TerminateDB (void)
{
    mysql_close (conn);
}

void TerminateDBConn (MYSQL* mConn)
{
    mysql_close (mConn);
}

void UpdateNoFilter (void)
{
    char         pcString[512];
    MYSQL_RES   *result;

    sprintf (pcString, 
             "UPDATE filter SET type=\"0\"");
    result = DBExec (conn, pcString);
    mysql_free_result (result);
}

void UpdateEthFilter (bool  bEthernetSrcSpec,      bool  bEthernetDestSpec,
                      bool  bEthernetProtocolSpec, char* cSourceMac,
                      char* cDestMac,
                      int   iEthernetProtocol)
{
    char         pcString[512];
    MYSQL_RES   *result;

    sprintf (pcString, 
             "UPDATE filter SET type=\"1\",eth_source_spec=%d, eth_dest_spec=%d,
              eth_prot_spec=%d, eth_source_addr=\"%s\", eth_dest_addr=\"%s\", 
              eth_number=%d where name=\"default\"",
              bEthernetSrcSpec,bEthernetDestSpec,bEthernetProtocolSpec,
              cSourceMac, cDestMac, iEthernetProtocol);
    result = DBExec (conn, pcString);
    mysql_free_result (result);
}

void UpdateIPFilter (bool bIPSrcSpec,     bool bIPDestSpec,
                     bool bIPSrcPortSpec, bool bIPDestPortSpec, bool bIPProtSpec,
                     char* cSourceIP,     char* cDestIP,
                     int iIPSrcPort,      int iIPDestPort,      int iIPProtocol)
{
    char         pcString[512];
    MYSQL_RES   *result;

    sprintf (pcString, 
             "UPDATE filter SET type=\"2\",ip_src_spec=%d, ip_dest_spec=%d, ip_prot_spec=%d,
              ip_src_port_spec=%d, ip_dest_port_spec=%d,
              ip_src_addr_mask=\"%s\", ip_dest_addr_mask=\"%s\",
              ip_src_portnr=%d, ip_dest_portnr=%d, ip_number=%d where name=\"default\"",
              bIPSrcSpec,bIPDestSpec, bIPProtSpec, 
              bIPSrcPortSpec, bIPDestPortSpec, 
              cSourceIP, cDestIP,
              iIPSrcPort, iIPDestPort, iIPProtocol);
    result = DBExec (conn, pcString);
    mysql_free_result (result);
}

void UpdateIPXFilter (bool bSNSpes, bool bSHSpec, bool bSSSpec,
                      bool bDNSpec, bool bDHSpec, bool bDSSpec,
                      bool bPacketType,
                      char* cSNet, char* cSHost, char* cSSocket,
                      char* cDNet, char* cDHost, char* cDSocket,
                      int iPacketType)
{
    char         pcString[1024];
    MYSQL_RES   *result;

    sprintf (pcString,
             "UPDATE filter SET type=\"3\",
              ipx_src_net_spec=%d,
              ipx_src_host_spec=%d,
              ipx_src_socket_spec=%d,
              ipx_dest_net_spec=%d,
              ipx_dest_host_spec=%d,
              ipx_dest_socket_spec=%d,
              ipx_prot_spec=%d,
              ipx_src_net=\"%s\",
              ipx_src_host=\"%s\",
              ipx_src_socket=\"%s\",
              ipx_dest_net=\"%s\",
              ipx_dest_host=\"%s\",
              ipx_dest_socket=\"%s\",
              ipx_number=%d where name=\"default\"",
              bSNSpes,bSHSpec, bSSSpec,
              bDNSpec, bDHSpec, bDSSpec,
              bPacketType,
              cSNet, cSHost,  cSSocket,
              cDNet, cDHost,  cDSocket,
              iPacketType);
    result = DBExec (conn, pcString);
    mysql_free_result (result);
}

void UpdateEthTrigger (bool bEthernetSrcSpec, bool bEthernetDestSpec,
                       bool bEthernetProtocolSpec, char* cSourceMac,
                       char* cDestMac,
                       int iEthernetProtocol)
{
    char         pcString[512];
    MYSQL_RES   *result;

    sprintf (pcString, 
             "UPDATE trigger SET starttype=\"3\",eth_source_spec=%d, eth_dest_spec=%d,
              eth_prot_spec=%d, eth_source_addr=\"%s\", eth_dest_addr=\"%s\", 
              eth_number=%d where name=\"default\"",
              bEthernetSrcSpec,bEthernetDestSpec,bEthernetProtocolSpec,
              cSourceMac, cDestMac, iEthernetProtocol );
    result = DBExec (conn, pcString);
    mysql_free_result (result);
}

void UpdateIPTrigger (bool bIPSrcSpec, bool bIPDestSpec,
                      bool bIPSrcPortSpec, bool bIPDestPortSpec, bool bIPProtSpec,
                      char* cSourceIP, char* cDestIP,
                      int iIPSrcPort, int iIPDestPort, int iIPProtocol)
{
    char         pcString[512];
    MYSQL_RES   *result;

    sprintf (pcString, 
             "UPDATE trigger SET starttype=\"4\",ip_src_spec=%d, ip_dest_spec=%d, ip_prot_spec=%d,
              ip_src_port_spec=%d, ip_dest_port_spec=%d,
              ip_src_addr=\"%s\", ip_dest_addr=\"%s\",
              ip_src_portnr=%d, ip_dest_portnr=%d, ip_number=%d where name=\"default\"",
              bIPSrcSpec,bIPDestSpec, bIPProtSpec, 
              bIPSrcPortSpec, bIPDestPortSpec, 
              cSourceIP, cDestIP,
              iIPSrcPort, iIPDestPort, iIPProtocol);
    result = DBExec (conn, pcString);
    
    mysql_free_result (result);
}

void UpdateIPXTrigger (bool bSNSpes, bool bSHSpec, bool bSSSpec,
                       bool bDNSpec, bool bDHSpec, bool bDSSpec,
                       bool bPacketType,
                       char* cSNet, char* cSHost, char* cSSocket,
                       char* cDNet, char* cDHost, char* cDSocket,
                       int iPacketType)
{
    char         pcString[1024];
    MYSQL_RES   *result;

    sprintf (pcString,
             "UPDATE trigger SET starttype=\"5\",
              ipx_src_net_spec=%d,
              ipx_src_host_spec=%d,
              ipx_src_socket_spec=%d,
              ipx_dest_net_spec=%d,			
              ipx_dest_host_spec=%d,
              ipx_dest_socket_spec=%d,
              ipx_prot_spec=%d,
              ipx_src_net=\"%s\",
              ipx_src_host=\"%s\",
              ipx_src_socket=\"%s\",
              ipx_dest_net=\"%s\",
              ipx_dest_host=\"%s\",
              ipx_dest_socket=\"%s\",
              ipx_number=%d where name=\"default\"",
              bSNSpes, bSHSpec, bSSSpec,
              bDNSpec, bDHSpec, bDSSpec,
              bPacketType,
              cSNet, cSHost, cSSocket,
              cDNet, cDHost, cDSocket,
              iPacketType);
    result = DBExec (conn, pcString);
    
    mysql_free_result (result);
}

void UpdateNoStartTrigger (void)
{
    char         pcString[512];
    MYSQL_RES   *result;

    sprintf (pcString, 
             "UPDATE trigger SET starttype=\"0\" where name=\"default\"");
    result = DBExec (conn, pcString);
    mysql_free_result (result); 
}

void UpdateNoStopTrigger (void)
{
    char         pcString[512];
    MYSQL_RES   *result;

    sprintf (pcString, 
             "UPDATE trigger SET stoptype=\"0\" where name=\"default\"");
    result = DBExec (conn, pcString);
    mysql_free_result (result); 
}

void UpdateCountTrigger (int iAantalPakketten)
{
    char         pcString[512];
    MYSQL_RES   *result;

    sprintf (pcString, 
             "UPDATE trigger SET stoptype=\"2\",aant_pak_spec=1, aant_pak=%d where name=\"default\"",
              iAantalPakketten);
    result = DBExec (conn, pcString);
    mysql_free_result (result);
}

void UpdateStartTimeTrigger(char* cYear,char* cMonth,char* cDay,char* cHour,char* cMin,char* cSec)
{
    char         pcString[512];
    MYSQL_RES   *result;
 
    sprintf (pcString, 
             "UPDATE trigger SET starttype=\"1\",time_start_year=\"%s\",time_start_month=\"%s\",time_start_day=\"%s\",
	      time_start_hour=\"%s\",time_start_min=\"%s\",time_start_sec=\"%s\" where name=\"default\"",
              cYear,cMonth,cDay,cHour,cMin,cSec );
    result = DBExec (conn, pcString);
    mysql_free_result (result);
}

void UpdateStopTimeTrigger(char* cYear,char* cMonth,char* cDay,char* cHour,char* cMin,char* cSec)
{
    char        pcString[512];
    MYSQL_RES  *result;
 
    sprintf (pcString, 
             "UPDATE trigger SET stoptype=\"1\",time_stop_year=\"%s\",time_stop_month=\"%s\",time_stop_day=\"%s\",
              time_stop_hour=\"%s\",time_stop_min=\"%s\",time_stop_sec=\"%s\" where name=\"default\"",
              cYear,cMonth,cDay,cHour,cMin,cSec );
    result = DBExec (conn, pcString);
    mysql_free_result (result);
}

/* EOF */