/*******************************************************************************
**                                                                            **
**  File:        status.c                                                     **
**  Description: With this program it is possible to perform administrative   **
**               actions on The WESP and on the wespdb                        **
**  Author:      Derick Rethans                                               **
**  Date:        1999-06-02                                                   **
**  Version:     1.0                                                          **
**  Lines:       217                                                          **
**                                                                            **
*******************************************************************************/

#include <unistd.h>
#include <fcntl.h>
#include <signal.h>
#include "html.h"
#include "db_interface.h"
#include "interface.h"
#include <stdlib.h>
#include "forms.h"

MYSQL * conn;

#define BUFSIZE 7

static int GetPID (void);
static void ShowInputbox (void);
static void ShowMenuForm (void);
static void ShowStateData (void);

/************* FUNCTIONS ******************************************************/

int main (void)
{
    int iPID;
    char cHelp[120];
    char cPass[120];

    HTMLHeader ("State");
    CGIParseEnv ();
    iPID = GetPID ();
    CGIGetEnv ("call", (char *) &cHelp, 118);
    CGIGetEnv ("password", (char *) &cPass, 118);
    ShowFormHeader ("The WESP: State");
    switch (atoi(cHelp))
    {
        case 0: ShowMenuForm();
	        break;
	case 1:
	 	if (iPID == 0)
		{
		    HTMLError (701);
	 	}
		else
	 	{
		    conn = InitDBConn ();
		    PutCall (CALL_STATUS);
	            TerminateDB ();
	            kill (iPID, SIGUSR2);
                    printf ("<A HREF=\"/cgi-bin/info?name=help#show_state\">help</A><HR>\n");
		    printf ("<P>\n<H3>Information about running WESP (PID=%d)</H3>\n", iPID);
		    sleep (1);
		    ShowStateData ();
		}
		break;
	case 2:
                ShowInputbox();
		break;
	case 3:
            	if (iPID == 0)
		{
		    HTMLError (701);
		}
		else
		{
                    if (cPass != NULL)
                    {
                        if (!strcmp(cPass, PASSWORD))
                        {
		            kill (iPID, SIGINT);
		            printf ("<P>\n<H3>The WESP (PID=%d) has been terminated .</H3>\n", iPID);
		        }
                        else
                        {
                            printf ("<P>\n <H3>Password is incorrect.</H3>\n");
                        }
                    }
                    else
                    {
                        printf ("<P>\n <H3>The password is empty.</H3>\n");
                    }
                }
                break;
	case 4:
	 	if (iPID == 0)
		{
		    HTMLError (701);
	 	}
		else
	 	{
		    conn = InitDBConn ();
	            PutCall (CALL_ABORT);
		    TerminateDB ();
	            kill (iPID, SIGUSR2);
		    printf ("<P>\n<H3>Running session has been aborted.</H3>\n");
		}
		break;
	case 5:
	 	if (iPID == 0)
		{
		    HTMLError (701);
	 	}
		else
	 	{
		    conn = InitDBConn ();
	            PutCall (CALL_RELOAD);
		    TerminateDB ();
	            kill (iPID, SIGUSR2);
		    printf ("<P>\n<H3>Trigger and filter settings are reloaded.</H3>\n");
		}
		break;
	case 6:
		conn = InitDBConn ();
	        EmptyPackets();
		TerminateDB ();
		printf ("<P>\n<H3>Database has been emptied.</H3>\n");
		break;
	default:
            ShowMenuForm();

    }
    HTMLBottom();
    return 0;
}

static int GetPID (void)
{
    int fd;
    char acWespID[BUFSIZE];
 
    if ((fd = open ("/var/lock/wesp", O_RDONLY)) == -1)
    {
	return 0;
    }
    else
    {
	while (read (fd, acWespID, BUFSIZE) > 0) 
	{
/*	    DoNothing(); */
	}
	acWespID [6] = 0;      
	return atoi (acWespID);  	
    }
}

static void ShowInputbox (void)
{
    printf ("<A HREF=\"/cgi-bin/info?name=help#adm_passwd\">help</A><HR>\n");
    printf ("<H3>Enter the Administrator password:</H3>\n");
    printf ("<FORM ACTION=\"/cgi-bin/status\" METHOD=%s>\n", METHOD);
    printf ("<INPUT TYPE=\"PASSWORD\" SIZE=\"8\" MAXLENGTH=\"8\" NAME=\"password\">\n");
    printf ("<INPUT TYPE=\"HIDDEN\" NAME=\"call\" VALUE=\"3\">\n");
    printf ("<INPUT TYPE=\"SUBMIT\" NAME=\"submit\" VALUE=\"Submit\">\n  ");
    printf ("</FORM>\n");
}

static void ShowMenuForm (void)
{
    printf ("<A HREF=\"/cgi-bin/info?name=help#state_menu\">help</A><HR>\n");
    printf ("Choose from the following options:\n<UL>\n");
    printf ("  <LI><A HREF=\"/cgi-bin/status?call=1\">Get status from the WESP</A></LI>\n");
    printf ("  <LI><A HREF=\"/cgi-bin/status?call=4\">Abort current session</A></LI>\n");
    printf ("  <LI><A HREF=\"/cgi-bin/status?call=5\">Reload trigger and filter settings</A></LI>\n");
    printf ("  <LI><A HREF=\"/cgi-bin/status?call=6\">Delete all packets from database</A></LI>\n");
    printf ("  <LI><A HREF=\"/cgi-bin/status?call=2\">Close the WESP</A></LI>\n");
    printf ("</UL>\n");    
}

static void ShowStateData (void)
{
    int iState;
    int iTotPack;
    int iSnifPack;
    int iFiltPack;
    int iSnifData;
    int iFiltData;
    
    conn = InitDBConn ();
    GetStatusData (&iState, &iTotPack, &iSnifPack, &iFiltPack, &iSnifData, &iFiltData);
    
    if (iState == 0)
    {
        HTMLError (702);
    }
    else
    {
        printf ("<TABLE CLASS=color BORDER=1>\n<TR><TD CLASS=left><A HREF=\"/cgi-bin/info?name=help#show_state_state\">State:</A> <TD>");
	switch (iState)
	{
	    case STATE_PRE:  printf ("The Wesp is Waiting for trigger");
	                     break;
	    case STATE_IN:   printf ("The Wesp is gathering packets");
	                     break;
	    case STATE_POST: printf ("The Wesp is sleeping");
	                     break;
	    default:         printf ("The Wesp is doing something I don't care about");
	                     break;
	}
	printf ("<TR><TD CLASS=left><A HREF=\"/cgi-bin/info?name=help#show_state_a\">Total # of packets:</A> <TD><B>%d</B>\n", iTotPack);
	printf ("<TR><TD CLASS=left><A HREF=\"/cgi-bin/info?name=help#show_state_b\">Total # of sniffed packets:</A> <TD><B>%d</B>\n", iSnifPack);
	printf ("<TR><TD CLASS=left><A HREF=\"/cgi-bin/info?name=help#show_state_c\">Total # of captured packets:</A> <TD><B>%d</B>\n", iFiltPack);
	printf ("<TR><TD CLASS=left><A HREF=\"/cgi-bin/info?name=help#show_state_d\">Bytes of sniffed data:</A> <TD><B>%d</B>\n", iSnifData);
	printf ("<TR><TD CLASS=left><A HREF=\"/cgi-bin/info?name=help#show_state_e\">Bytes of captured data:</A> <TD><B>%d</B>\n", iFiltData);
	printf ("</TABLE>\n");
    }		    
    TerminateDB ();
}

/* EOF */