/*******************************************************************************
**                                                                            **
** File:        create_tables.c                                               **
** Description: Program creates tables into the database wespdb               **
** Author:      Jeroen Scheeres                                               **   
** Date:        1999-06-03                                                    **
** Version:     1.0                                                           **
** Lines:       317                                                           **
**                                                                            **
*******************************************************************************/

#include <mysql/mysql.h>

#include "db_interface.h"

static MYSQL* conn;
static MYSQL_RES* result;

int main (void)
{
/* Connecting database to server */
    
    conn = InitDBConn ();
    
/* Create tables */
    
    result = DBExec (conn, "CREATE TABLE hardware_types (
			    ht_number int2 not null, 
			    hardware_type char(40) not null,
			    primary key (ht_number))");

    result = DBExec (conn, "CREATE TABLE ethernet_types (
			    number int4 not null,
			    ethernet_type char(20) not null,
			    primary key (number))");
			    
    result = DBExec (conn, "CREATE TABLE ip_types (
			    number int2 not null,
			    ip_type char(10) not null,
			    primary key (number))");

    result = DBExec (conn, "CREATE TABLE ipx_types (
			    number int2 not null,
			    ipx_type char(40) not null,
			    primary key (number))");

    result = DBExec (conn,"CREATE TABLE arp_operations (
			    o_number int2 not null,
			    operation char(15) not null,
			    primary key (o_number))");    

    result = DBExec (conn,"CREATE TABLE portnr (			
			    port char(4) not null,
			    portname char (35) not null,
			    primary key (port))");

    result = DBExec(conn,"CREATE TABLE packet (
			    timestamp char(20) not null,
			    OSILayer2Prot int4 not null,
			    OSILayer3Prot int4 not null,
			    OSILayer4Prot int4 not null,
			    dest_addr char(12) not null,
			    src_addr char(12) not null,
			    type int4 not null,
			    packet_length int4 not null,
			    snifstuff text,
			    primary key (timestamp))");

    result = DBExec(conn,"CREATE TABLE ip (
			    timestamp char(20) not null,
			    version int2 not null, 
			    hdr_len int2 not null,
			    tos char(1) not null,
			    tot_len int2 not null,
			    id int4 not null,
			    d bool not null,
			    m bool not null,
			    frag_offset int2 not null,
			    ttl int2 not null,
			    number int2 not null,
			    src_ip char(8) not null,
			    dest_ip char(8) not null,
			    primary key (timestamp),
			    foreign key (timestamp)
				references ethernet (timestamp),
			    foreign key (number)
				references ip_types (number))");

    result = DBExec (conn,"CREATE TABLE arp (
			    timestamp char(20) not null,
			    ht_number int2 not null,
			    number int2 not null,
			    hard_addr_length int2 not null,
			    ip_addr_length int2 not null,
			    o_number int2 not null,
			    sender_mac char(12) not null,
			    sender_ip char(8) not null,
			    target_mac char(12) not null,
			    target_ip char(8) not null,
			    primary key (timestamp),
			    foreign key (ht_number)
				references hardware_types (ht_number),
			    foreign key (number)
				references ethernet_types (number),
			    foreign key (o_number)
				references operations (o_number),
			    foreign key (timestamp)
				references ethernet (timestamp))");
    				

    result = DBExec (conn,"CREATE TABLE ipx (
			    timestamp char(20) not null,
			    subtype int2 not null,
			    length int4 not null,
			    transp_cntrl char(1) not null,
			    packet_type char(1) not null,
			    dest_network char(8) not null,
			    dest_host char(12) not null,
			    dest_socket char(4) not null,
			    src_network  char(8) not null,
			    src_host char(12) not null,
			    src_socket char(4) not null,
			    primary key (timestamp),
			    foreign key (packet_type)
				references ipx_types (number),
			    foreign key (timestamp)
				references ethernet (timestamp))");			   

    result = DBExec (conn,"CREATE TABLE spx (
			    timestamp char(20) not null,
			    con_cntrl char(1) not null,
			    datastream_type char(1) not null,
			    src_con_id int2 not null,
			    dest_con_id int2 not null,
			    seqnr int2 not null,
			    acknr int2 not null,
			    allocnr int2 not null,
			    primary key (timestamp),
			    foreign key (timestamp)
			    	references ethernet (timestamp))");			   
	
    result = DBExec (conn,"CREATE TABLE tcp (
			    timestamp char(20) not null,
			    src_port int2 not null,
			    dest_port int2 not null,
			    seqnr int4 not null,
			    acknr int4 not null,
			    hdr_length char(1) not null,
			    codebits char(1) not null,
			    window int4 not null,
			    primary key (timestamp),
			    foreign key (timestamp)
				references ethernet (timestamp))");			   
				
    result = DBExec (conn,"CREATE TABLE udp (			
			    timestamp char(20) not null,
			    src_port int2 not null,
			    dest_port int2 not null,
			    length int2 not null,
			    primary key (timestamp),
			    foreign key (timestamp)
				references ethernet (timestamp))");			   

    result = DBExec (conn, "CREATE TABLE icmp_types (
			    number int2 not null,
			    type char (30) not null,
			    primary key (number))");

    result = DBExec (conn, "CREATE TABLE icmp (
			    timestamp char(20) not null,
			    type int2 not null,
			    code int2 not null,
			    ident int4 not null,
			    seqnr int4 not null,
			    primary key (timestamp),
			    foreign key (type) 
				references icmp_types (number),
			    foreign key (timestamp) 
				references ethernet (timestamp))");			   

    result = DBExec (conn, "CREATE TABLE trigger (
			    name char(16) not null,
			    starttype int not null,
			    stoptype int not null,
			    time_start_year char(4) not null,
			    time_start_month char(2) not null,
			    time_start_day char(2) not null,
			    time_start_hour char(2) not null,
			    time_start_min char(2) not null,
			    time_start_sec char(2) not null,
			    time_stop_year char(4) not null,
			    time_stop_month char(2) not null,
			    time_stop_day char(2) not null,
			    time_stop_hour char(2) not null,
			    time_stop_min char(2) not null,
			    time_stop_sec char(2) not null,
			    eth_source_spec bool not null,
			    eth_source_addr char(12) not null,
			    eth_dest_spec bool not null,
			    eth_dest_addr char(12) not null,
			    eth_prot_spec bool not null,
			    eth_number int4 not null,
			    ip_src_spec bool not null,
			    ip_src_addr char(8) not null,
			    ip_dest_spec bool not null,
			    ip_dest_addr char(8) not null,
			    ip_src_port_spec bool not null,
			    ip_src_portnr int2 not null,
			    ip_dest_port_spec bool not null,
			    ip_dest_portnr int2 not null,
			    ip_prot_spec bool not null,
			    ip_number int2 not null,
			    ipx_src_net_spec bool not null,
			    ipx_src_net char(8) not null,
			    ipx_src_host_spec bool not null,
			    ipx_src_host char(12) not null,
			    ipx_src_socket_spec bool not null,
			    ipx_src_socket char(4) not null,
			    ipx_dest_net_spec bool not null,
			    ipx_dest_net char(8) not null,
			    ipx_dest_host_spec bool not null,
			    ipx_dest_host char(12) not null,
			    ipx_dest_socket_spec bool not null,
			    ipx_dest_socket char(4) not null,
			    ipx_prot_spec bool not null,
			    ipx_number int2 not null,
			    aant_pak_spec bool not null,
			    aant_pak int not null,
			    ip_duplex bool not null,
			    primary key (name),
			    foreign key (eth_number)
				references ethernet_types (number),
			    foreign key (ip_number)
				references ip_types (number),
			    foreign key (ipx_number)
				references ipx_types (number))");	    

    result = DBExec (conn, "CREATE TABLE filter (
			    name char(16) not null,
			    type int not null,
			    eth_source_spec bool not null,
			    eth_source_addr char(12) not null,
			    eth_dest_spec bool not null,
			    eth_dest_addr char(12) not null,
			    eth_prot_spec bool not null,
			    eth_number int4 not null,
			    ip_src_spec bool not null,
			    ip_src_addr_mask char(8) not null,
			    ip_dest_spec bool not null,
			    ip_dest_addr_mask char(8) not null,
			    ip_src_port_spec bool not null,
			    ip_src_portnr int2 not null,
			    ip_dest_port_spec bool not null,
			    ip_dest_portnr int2 not null,
			    ip_prot_spec bool not null,
			    ip_number int2 not null,
			    ipx_src_net_spec bool not null,
			    ipx_src_net char(8) not null,
			    ipx_src_host_spec bool not null,
			    ipx_src_host char(12) not null,
			    ipx_src_socket_spec bool not null,
			    ipx_src_socket char(4) not null,
			    ipx_dest_net_spec bool not null,
			    ipx_dest_net char(8) not null,
			    ipx_dest_host_spec bool not null,
			    ipx_dest_host char(12) not null,
			    ipx_dest_socket_spec bool not null,
			    ipx_dest_socket char(4) not null,
			    ipx_prot_spec bool not null,
			    ipx_number int2 not null,
			    ip_duplex bool not null,
			    primary key (name),
			    foreign key (eth_number)
				references ethernet_types (number),
			    foreign key (ip_number)
				references ip_types (number),
			    foreign key (ipx_number)
				references ipx_types (number))");
    
    result = DBExec (conn, "create table status (
                            CallID int not null, 
                            State int not null,
                            TotalPackets int not null, 
                            SniffedPackets int not null,
			    FilterredPackets int not null,
			    SniffedData int not null,
			    FilterredData int not null)");

    result = DBExec (conn, "create table usr_ip (
			    username char(32) not null,
			    ip_addr char(8) not null,
			    primary key (username))");

    result = DBExec (conn, "create table usr_eth (
			    username char(32) not null,
			    eth_addr char(12) not null,
			    primary key (username))");

/* Create index on table packet */

    result = DBExec(conn,"CREATE INDEX idxPacketTS on packet (timestamp)");

    result = DBExec (conn, "GRANT ALL ON wespdb.* to root");

/* Terminate database */ 

    TerminateDB ();
    
    return 0;
}